@@ -12,7 +12,7 @@ from typing import Literal, Any
 
 import mistune
 
-from .utils import compare_string_with_pattern
+from .utils import assert_string_match_pattern, print_string_match_pattern
 
 
 @dataclass
@@ -115,9 +115,14 @@ class Check:
             else:
                 expected = expected.strip().replace('\r', '')
                 actual = actual.strip().replace('\r', '')
-            assert compare_string_with_pattern(pattern=expected, string=actual), \
-                f"{self.code=} result does not match expected: {actual!r} != {expected!r}"
-            print('OK')
+            try:
+                assert_string_match_pattern(pattern=expected, string=actual)
+            except ValueError:
+                print('FAIL: ')
+                print_string_match_pattern(pattern=expected, string=actual, depth=depth)
+                raise
+            else:
+                print('OK')
         else:
             print('IGNORE')
 
